==> nextcloud-24.0.10.tgz: nextcloud/apps/oauth2/l10n/eu.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Zure bezeroak ez du konektatzeko baimenik. Esan iezaiozu zure bezeroaren administratzaileari.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Berbideraketa egiteko URLa URL oso bat izan behar da, adibidez: https://zuredomeinua.eus/karpeta",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Beste web aplikazio batzuen bidez egindako OAuth2 erako autentikazioa egitea baimentzen du",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 aplikazioak, zerbitzu hori eskaintzen duten beste web aplikazio batzuen bidez autentikazioa egiten konfiguratzeko aukera eskaintzen die sistemaren kudeatzaileei.",
    "OAuth 2.0 clients" : "OAuth 2.0 bezeroak",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0k kanpo zerbitzuei {instanceName} instantziara sartzeko baimena eskatzea baimentzen die.",
    "Add client" : "Gehitu bezeroa",
    "Name" : "Izena",
    "Redirection URI" : "Birbideraketaren URI",
    "Add" : "Gehitu",
    "Client Identifier" : "Bezeroaren Identifikadorea",
    "Secret" : "Sekretua",
    "Show client secret" : "Erakutsi bezeroaren sekretua",
    "Delete" : "Ezabatu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.5.tgz: nextcloud/apps/oauth2/l10n/eu.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Zure bezeroak ez du konektatzeko baimenik. Esan iezaiozu zure bezeroaren administratzaileari.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Berbideraketa egiteko URLa URL oso bat izan behar da, adibidez: https://zuredomeinua.eus/karpeta",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Beste web aplikazio batzuen bidez egindako OAuth2 erako autentikazioa egitea baimentzen du",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 aplikazioak, zerbitzu hori eskaintzen duten beste web aplikazio batzuen bidez autentikazioa egiten konfiguratzeko aukera eskaintzen die sistemaren kudeatzaileei.",
    "OAuth 2.0 clients" : "OAuth 2.0 bezeroak",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0k kanpo zerbitzuei {instanceName} instantziara sartzeko baimena eskatzea baimentzen die.",
    "Name" : "Izena",
    "Redirection URI" : "Birbideraketaren URI",
    "Client Identifier" : "Bezeroaren Identifikadorea",
    "Secret key" : "Gako sekretua",
    "Add client" : "Gehitu bezeroa",
    "Add" : "Gehitu",
    "Show client secret" : "Erakutsi bezeroaren sekretua",
    "Delete" : "Ezabatu",
    "Secret" : "Sekretua"
},
"nplurals=2; plural=(n != 1);");
